##  2. Modeling middleware as an IT Component
Pros:
  * Enables IT Landscape, Roadmapping and Matrix Reporting.
  * Allows for a direct link to the Applications connected to the middleware without having to
double-model it as an Application that provides a cleaner IT landscape.
  * Enables Free Draw modeling and limited Data Flow Diagrams.
  * Provides a clear view of the IT landscape and relations between Applications and IT Components.

![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274829757a4410148df1f8aa90148887_LowRes.png) ![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274605d57a44101483c2aff8f30e7ad0_LowRes.png)
Cons:
  * Does not allow for robust Application integration architecture modeling using Data Flows.

![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d1d627a4410148a6da50370ddc606_LowRes.png)
  * Limited to IT landscape reports and without a connection to the business aspect of the organization
(Business Capabilities and User Groups).
  * In the below view, we are able to see that the Applications are red and exposed to Technical Risk, but the underlying link to the ESB which is causing this is missing.

![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27577e3d7a441014b1fddee44de0074c_LowRes.png)
